* mln/core/image/image3d.hh,
* mln/core/internal/box_impl.hh,
* mln/core/site_set/box.hh,
* mln/debug/slices_2d.hh,
* mln/geom/all.hh,
* mln/geom/size3d.hh,
* mln/linear/gaussian.hh,
* mln/linear/gaussian/impl.hh,
* mln/make/box3d.hh,
* mln/make/image.hh,
* mln/make/image3d.hh,
* mln/registration/icp.hh,
* tests/core/alias/box3d.cc,
* tests/core/image/image3d.cc,
* tests/geom/Makefile.am,
* tests/io/pbms/load.cc,
* tests/io/pgms/load.cc,
* tests/io/ppms/load.cc: Rename nslices to nslis.
* mln/geom/nslices.hh,
* tests/geom/nslices.cc: Rename as...
* mln/geom/nslis.hh,
* tests/geom/nslis.cc: ...this.
---
milena/ChangeLog | 29 ++++++++++++++
milena/mln/core/image/image3d.hh | 14 +++---
milena/mln/core/internal/box_impl.hh | 8 ++--
milena/mln/core/site_set/box.hh | 10 ++--
milena/mln/debug/slices_2d.hh | 20 +++++-----
milena/mln/geom/all.hh | 6 +-
milena/mln/geom/{nslices.hh => nslis.hh} | 14 +++---
milena/mln/geom/size3d.hh | 4 +-
milena/mln/linear/gaussian.hh | 10 ++--
milena/mln/linear/gaussian/impl.hh | 12 +++---
milena/mln/make/box3d.hh | 16 ++++----
milena/mln/make/image.hh | 8 ++--
milena/mln/make/image3d.hh | 9 ++--
milena/mln/registration/icp.hh | 4 +-
milena/tests/core/alias/box3d.cc | 6 +-
milena/tests/core/image/image3d.cc | 12 +++---
milena/tests/geom/Makefile.am | 8 ++--
milena/tests/geom/{nslices.cc => nslis.cc} | 8 ++--
milena/tests/io/pbms/load.cc | 6 +-
milena/tests/io/pgms/load.cc | 6 +-
milena/tests/io/ppms/load.cc | 6 +-
scribo/sandbox/green/mln/clustering/k_mean.hh | 4 +-
scribo/sandbox/green/mln/display/project_histo.hh | 44 ++++++++++----------
23 files changed, 147 insertions(+), 117 deletions(-)
rename milena/mln/geom/{nslices.hh => nslis.hh} (86%)
rename milena/tests/geom/{nslices.cc => nslis.cc} (88%)
diff --git a/milena/ChangeLog b/milena/ChangeLog
index 33c4aa3..77e5081 100644
--- a/milena/ChangeLog
+++ b/milena/ChangeLog
@@ -1,3 +1,32 @@
+2011-09-02 Guillaume Lazzara <z(a)lrde.epita.fr>
+
+ Rename back nslices to nslis.
+
+ * mln/core/image/image3d.hh,
+ * mln/core/internal/box_impl.hh,
+ * mln/core/site_set/box.hh,
+ * mln/debug/slices_2d.hh,
+ * mln/geom/all.hh,
+ * mln/geom/size3d.hh,
+ * mln/linear/gaussian.hh,
+ * mln/linear/gaussian/impl.hh,
+ * mln/make/box3d.hh,
+ * mln/make/image.hh,
+ * mln/make/image3d.hh,
+ * mln/registration/icp.hh,
+ * tests/core/alias/box3d.cc,
+ * tests/core/image/image3d.cc,
+ * tests/geom/Makefile.am,
+ * tests/io/pbms/load.cc,
+ * tests/io/pgms/load.cc,
+ * tests/io/ppms/load.cc: Rename nslices to nslis.
+
+ * mln/geom/nslices.hh,
+ * tests/geom/nslices.cc: Rename as...
+
+ * mln/geom/nslis.hh,
+ * tests/geom/nslis.cc: ...this.
+
2011-08-08 Guillaume Lazzara <z(a)lrde.epita.fr>
* doc/figures/ima2d-rot-2.ppm: Regen.
diff --git a/milena/mln/core/image/image3d.hh b/milena/mln/core/image/image3d.hh
index 865507f..86c8f23 100644
--- a/milena/mln/core/image/image3d.hh
+++ b/milena/mln/core/image/image3d.hh
@@ -1,5 +1,5 @@
-// Copyright (C) 2007, 2008, 2009, 2010 EPITA Research and Development
-// Laboratory (LRDE)
+// Copyright (C) 2007, 2008, 2009, 2010, 2011 EPITA Research and
+// Development Laboratory (LRDE)
//
// This file is part of Olena.
//
@@ -165,7 +165,7 @@ namespace mln
/// Constructor with the numbers of indexes and the
/// border thickness.
- image3d(int nslices, int nrows, int ncols, unsigned bdr = border::thickness);
+ image3d(int nslis, int nrows, int ncols, unsigned bdr = border::thickness);
/// Initialize an empty image.
@@ -209,7 +209,7 @@ namespace mln
/// Give the number of slices.
- unsigned nslices() const;
+ unsigned nslis() const;
/// Give the number of rows.
unsigned nrows() const;
@@ -396,9 +396,9 @@ namespace mln
template <typename T>
inline
- image3d<T>::image3d(int nslices, int nrows, int ncols, unsigned bdr)
+ image3d<T>::image3d(int nslis, int nrows, int ncols, unsigned bdr)
{
- init_(make::box3d(nslices, nrows, ncols), bdr);
+ init_(make::box3d(nslis, nrows, ncols), bdr);
}
template <typename T>
@@ -512,7 +512,7 @@ namespace mln
template <typename T>
inline
unsigned
- image3d<T>::nslices() const
+ image3d<T>::nslis() const
{
mln_precondition(this->is_valid());
return this->data_->b_.len(0);
diff --git a/milena/mln/core/internal/box_impl.hh b/milena/mln/core/internal/box_impl.hh
index c9fbd6a..bb176c7 100644
--- a/milena/mln/core/internal/box_impl.hh
+++ b/milena/mln/core/internal/box_impl.hh
@@ -1,5 +1,5 @@
-// Copyright (C) 2007, 2008, 2009, 2010 EPITA Research and Development
-// Laboratory (LRDE)
+// Copyright (C) 2007, 2008, 2009, 2010, 2011 EPITA Research and
+// Development Laboratory (LRDE)
//
// This file is part of Olena.
//
@@ -57,7 +57,7 @@ namespace mln
struct box_impl_<3, C, E>
{
/// Give the number of slis.
- unsigned nslices() const;
+ unsigned nslis() const;
/// Give the minimum sli.
C min_sli() const;
@@ -144,7 +144,7 @@ namespace mln
template <typename C, typename E>
inline
- unsigned box_impl_<3, C, E>::nslices() const
+ unsigned box_impl_<3, C, E>::nslis() const
{
return internal::force_exact<E>(*this).bbox().len(0);
}
diff --git a/milena/mln/core/site_set/box.hh b/milena/mln/core/site_set/box.hh
index c061321..12b049a 100644
--- a/milena/mln/core/site_set/box.hh
+++ b/milena/mln/core/site_set/box.hh
@@ -1,5 +1,5 @@
-// Copyright (C) 2007, 2008, 2009, 2010 EPITA Research and Development
-// Laboratory (LRDE)
+// Copyright (C) 2007, 2008, 2009, 2010, 2011 EPITA Research and
+// Development Laboratory (LRDE)
//
// This file is part of Olena.
//
@@ -125,7 +125,7 @@ namespace mln
/// (sizes) w.r.t. the dimension.
explicit box(mln_coord(P) ninds);
box(mln_coord(P) nrows, mln_coord(P) ncols);
- box(mln_coord(P) nslices, mln_coord(P) nrows, mln_coord(P) ncols);
+ box(mln_coord(P) nslis, mln_coord(P) nrows, mln_coord(P) ncols);
/// \}
/*! \brief Test if \p p belongs to the box.
@@ -310,11 +310,11 @@ namespace mln
template <typename P>
inline
- box<P>::box(mln_coord(P) nslices, mln_coord(P) nrows, mln_coord(P) ncols)
+ box<P>::box(mln_coord(P) nslis, mln_coord(P) nrows, mln_coord(P) ncols)
{
metal::bool_<(dim == 3)>::check();
pmin_ = literal::origin;
- pmax_ = P(nslices - 1, nrows - 1, ncols - 1);
+ pmax_ = P(nslis - 1, nrows - 1, ncols - 1);
mln_postcondition(is_valid());
}
diff --git a/milena/mln/debug/slices_2d.hh b/milena/mln/debug/slices_2d.hh
index 50473a4..11e0aaa 100644
--- a/milena/mln/debug/slices_2d.hh
+++ b/milena/mln/debug/slices_2d.hh
@@ -1,4 +1,4 @@
-// Copyright (C) 2008, 2009, 2010 EPITA Research and Development
+// Copyright (C) 2008, 2009, 2010, 2011 EPITA Research and Development
// Laboratory (LRDE)
//
// This file is part of Olena.
@@ -87,11 +87,11 @@ namespace mln
mln_precondition(input.is_valid());
mln_precondition(n_horizontal > 0 && n_vertical > 0);
- mln_precondition(input.nslices() <= n_horizontal * n_vertical);
+ mln_precondition(input.nslis() <= n_horizontal * n_vertical);
image2d<mln_value(I)> output(input.nrows() * n_vertical,
input.ncols() * n_horizontal);
- if (input.nslices() != n_horizontal * n_vertical)
+ if (input.nslis() != n_horizontal * n_vertical)
data::fill(output, bg);
const point3d& p_min = input.domain().pmin();
@@ -133,23 +133,23 @@ namespace mln
return n;
}
- void slices2d_helper(float nslices, float nrows, float ncols,
+ void slices2d_helper(float nslis, float nrows, float ncols,
float ratio_hv,
unsigned& n_horizontal,
unsigned& n_vertical)
{
if (ratio_hv > 1.f)
{
- float n_v = std::sqrt(nslices * ncols / ratio_hv / nrows);
+ float n_v = std::sqrt(nslis * ncols / ratio_hv / nrows);
n_vertical = internal::round_up(n_v);
- float n_h = nslices / float(n_vertical);
+ float n_h = nslis / float(n_vertical);
n_horizontal = internal::round_up(n_h);
}
else
{
- float n_h = std::sqrt(nrows * nslices * ratio_hv / ncols);
+ float n_h = std::sqrt(nrows * nslis * ratio_hv / ncols);
n_horizontal = internal::round_up(n_h);
- float n_v = nslices / float(n_horizontal);
+ float n_v = nslis / float(n_horizontal);
n_vertical = internal::round_up(n_v);
}
}
@@ -171,10 +171,10 @@ namespace mln
mln_precondition(ratio_hv > 0.f);
unsigned n_horizontal, n_vertical;
- internal::slices2d_helper(input.nslices(), input.nrows(), input.ncols(),
+ internal::slices2d_helper(input.nslis(), input.nrows(), input.ncols(),
ratio_hv,
n_horizontal, n_vertical);
- mln_assertion(n_horizontal * n_vertical >= input.nslices());
+ mln_assertion(n_horizontal * n_vertical >= input.nslis());
image2d<mln_value(I)> output = slices_2d(input, n_horizontal, n_vertical,
bg);
diff --git a/milena/mln/geom/all.hh b/milena/mln/geom/all.hh
index c03db08..70a719f 100644
--- a/milena/mln/geom/all.hh
+++ b/milena/mln/geom/all.hh
@@ -1,5 +1,5 @@
-// Copyright (C) 2007, 2008, 2009, 2010 EPITA Research and Development
-// Laboratory (LRDE)
+// Copyright (C) 2007, 2008, 2009, 2010, 2011 EPITA Research and
+// Development Laboratory (LRDE)
//
// This file is part of Olena.
//
@@ -60,7 +60,7 @@ namespace mln
# include <mln/geom/ninds.hh>
# include <mln/geom/nrows.hh>
# include <mln/geom/nsites.hh>
-# include <mln/geom/nslices.hh>
+# include <mln/geom/nslis.hh>
# include <mln/geom/pmin_pmax.hh>
# include <mln/geom/rotate.hh>
# include <mln/geom/seeds2tiling.hh>
diff --git a/milena/mln/geom/nslices.hh b/milena/mln/geom/nslis.hh
similarity index 86%
rename from milena/mln/geom/nslices.hh
rename to milena/mln/geom/nslis.hh
index 9e22eb9..f6de945 100644
--- a/milena/mln/geom/nslices.hh
+++ b/milena/mln/geom/nslis.hh
@@ -24,8 +24,8 @@
// exception does not however invalidate any other reasons why the
// executable file might be covered by the GNU General Public License.
-#ifndef MLN_GEOM_NSLICES_HH
-# define MLN_GEOM_NSLICES_HH
+#ifndef MLN_GEOM_NSLIS_HH
+# define MLN_GEOM_NSLIS_HH
/// \file
///
@@ -43,19 +43,19 @@ namespace mln
/// Give the number of slices of an image.
template <typename I>
- unsigned nslices(const Image<I>& ima);
+ unsigned nslis(const Image<I>& ima);
# ifndef MLN_INCLUDE_ONLY
template <typename I>
inline
- unsigned nslices(const Image<I>& ima)
+ unsigned nslis(const Image<I>& ima)
{
mln_precondition(exact(ima).is_valid());
- unsigned nslices = geom::max_sli(ima) - geom::min_sli(ima) + 1;
+ unsigned nslis = geom::max_sli(ima) - geom::min_sli(ima) + 1;
- return nslices;
+ return nslis;
}
# endif // ! MLN_INCLUDE_ONLY
@@ -65,4 +65,4 @@ namespace mln
} // end of namespace mln
-#endif // ! MLN_GEOM_NSLICES_HH
+#endif // ! MLN_GEOM_NSLIS_HH
diff --git a/milena/mln/geom/size3d.hh b/milena/mln/geom/size3d.hh
index 114e9a4..17670a8 100644
--- a/milena/mln/geom/size3d.hh
+++ b/milena/mln/geom/size3d.hh
@@ -1,4 +1,4 @@
-// Copyright (C) 2007, 2009, 2010 EPITA Research and Development
+// Copyright (C) 2007, 2009, 2010, 2011 EPITA Research and Development
// Laboratory (LRDE)
//
// This file is part of Olena.
@@ -32,7 +32,7 @@
* \brief Facade to include 3D size access routines.
*/
-# include <mln/geom/nslices.hh>
+# include <mln/geom/nslis.hh>
# include <mln/geom/nrows.hh>
# include <mln/geom/ncols.hh>
diff --git a/milena/mln/linear/gaussian.hh b/milena/mln/linear/gaussian.hh
index 314c6e0..4bb7773 100644
--- a/milena/mln/linear/gaussian.hh
+++ b/milena/mln/linear/gaussian.hh
@@ -1,5 +1,5 @@
-// Copyright (C) 2001, 2002, 2003, 2004, 2007, 2008, 2009, 2010 EPITA
-// Research and Development Laboratory (LRDE)
+// Copyright (C) 2001, 2002, 2003, 2004, 2007, 2008, 2009, 2010, 2011
+// EPITA Research and Development Laboratory (LRDE)
//
// This file is part of Olena.
//
@@ -51,7 +51,7 @@
# include <mln/geom/min_sli.hh>
# include <mln/geom/max_sli.hh>
# include <mln/geom/ninds.hh>
-# include <mln/geom/nslices.hh>
+# include <mln/geom/nslis.hh>
# include <mln/data/paste.hh>
# include <mln/data/stretch.hh>
# include <mln/algebra/vec.hh>
@@ -442,11 +442,11 @@ namespace mln
point3d(static_cast<def::coord>(-img.border()),
static_cast<def::coord>(j),
static_cast<def::coord>(k)),
-
point3d(static_cast<def::coord>(geom::nslices(img) - 1 +
+
point3d(static_cast<def::coord>(geom::nslis(img) - 1 +
img.border()),
static_cast<def::coord>(j),
static_cast<def::coord>(k)),
- geom::nslices(img) + 2 *
+ geom::nslis(img) + 2 *
img.border(),
dpoint3d(1, 0, 0));
}
diff --git a/milena/mln/linear/gaussian/impl.hh b/milena/mln/linear/gaussian/impl.hh
index 9f7332b..dfe8d1e 100644
--- a/milena/mln/linear/gaussian/impl.hh
+++ b/milena/mln/linear/gaussian/impl.hh
@@ -1,4 +1,4 @@
-// Copyright (C) 2001, 2002, 2003, 2004, 2008, 2009, 2010 EPITA
+// Copyright (C) 2001, 2002, 2003, 2004, 2008, 2009, 2010, 2011 EPITA
// Research and Development Laboratory (LRDE)
//
// This file is part of Olena.
@@ -45,7 +45,7 @@
# include <mln/geom/ncols.hh>
# include <mln/geom/nrows.hh>
# include <mln/geom/ninds.hh>
-# include <mln/geom/nslices.hh>
+# include <mln/geom/nslis.hh>
# include <mln/data/paste.hh>
# include <mln/data/stretch.hh>
# include <mln/algebra/vec.hh>
@@ -246,11 +246,11 @@ namespace mln
point3d(static_cast<def::coord>(-img.border()),
static_cast<def::coord>(j),
static_cast<def::coord>(k)),
- point3d(static_cast<def::coord>(geom::nslices(img) - 1 +
+ point3d(static_cast<def::coord>(geom::nslis(img) - 1 +
img.border()),
static_cast<def::coord>(j),
static_cast<def::coord>(k)),
- geom::nslices(img) + 2 *
+ geom::nslis(img) + 2 *
img.border(),
dpoint3d(1, 0, 0));
}
@@ -259,7 +259,7 @@ namespace mln
if (dir == 1)
{
// Apply on rows.
- for (unsigned i = 0; i < geom::nslices(img); ++i)
+ for (unsigned i = 0; i < geom::nslis(img); ++i)
for (unsigned k = 0; k < geom::ncols(img); ++k)
recursivefilter_<mln_value(I)>(img, coef,
point3d(static_cast<def::coord>(i),
@@ -277,7 +277,7 @@ namespace mln
if (dir == 2)
{
// Apply on columns.
- for (unsigned i = 0; i < geom::nslices(img); ++i)
+ for (unsigned i = 0; i < geom::nslis(img); ++i)
for (unsigned j = 0; j < geom::nrows(img); ++i)
recursivefilter_<mln_value(I)>(img, coef,
point3d(static_cast<def::coord>(i),
diff --git a/milena/mln/make/image.hh b/milena/mln/make/image.hh
index c5dadee..ef80c57 100644
--- a/milena/mln/make/image.hh
+++ b/milena/mln/make/image.hh
@@ -1,5 +1,5 @@
-// Copyright (C) 2007, 2008, 2009, 2010 EPITA Research and Development
-// Laboratory (LRDE)
+// Copyright (C) 2007, 2008, 2009, 2010, 2011 EPITA Research and
+// Development Laboratory (LRDE)
//
// This file is part of Olena.
//
@@ -114,10 +114,10 @@ namespace mln
mlc_bool(S != 0 && R != 0 && C != 0)::check();
mln::image3d<V> tmp(S, R, C);
const def::coord
- nslices = static_cast<def::coord>(S),
+ nslis = static_cast<def::coord>(S),
nrows = static_cast<def::coord>(R),
ncols = static_cast<def::coord>(C);
- for (def::coord sli = 0; sli < nslices; ++sli)
+ for (def::coord sli = 0; sli < nslis; ++sli)
for (def::coord row = 0; row < nrows; ++row)
for (def::coord col = 0; col < ncols; ++col)
opt::at(tmp, sli, row, col) = values[sli][row][col];
diff --git a/milena/mln/make/image3d.hh b/milena/mln/make/image3d.hh
index f924e63..768ba79 100644
--- a/milena/mln/make/image3d.hh
+++ b/milena/mln/make/image3d.hh
@@ -1,4 +1,5 @@
-// Copyright (C) 2008, 2009 EPITA Research and Development Laboratory (LRDE)
+// Copyright (C) 2008, 2009, 2011 EPITA Research and Development
+// Laboratory (LRDE)
//
// This file is part of Olena.
//
@@ -71,12 +72,12 @@ namespace mln
mlc_equal(mln_domain(I), mln::box2d)::check();
mln_precondition(! ima.is_empty());
- def::coord n_slices = ima.nelements();
+ def::coord n_slis = ima.nelements();
mln::box2d b = ima[0].domain();
mln::box3d b_ = make::box3d(0, b.pmin().row(), b.pmin().col(),
- n_slices - 1, b.pmax().row(), b.pmax().col());
+ n_slis - 1, b.pmax().row(), b.pmax().col());
mln::image3d<mln_value(I)> output(b_);
- for (def::coord sli = 0; sli < n_slices; ++sli)
+ for (def::coord sli = 0; sli < n_slis; ++sli)
{
mln_assertion(ima[sli].domain() == b);
data::paste(ima[sli], slice(output, sli).rw());
diff --git a/milena/mln/registration/icp.hh b/milena/mln/registration/icp.hh
index 1b824db..9448a2f 100644
--- a/milena/mln/registration/icp.hh
+++ b/milena/mln/registration/icp.hh
@@ -1,4 +1,4 @@
-// Copyright (C) 2008, 2009, 2010 EPITA Research and Development
+// Copyright (C) 2008, 2009, 2010, 2011 EPITA Research and Development
// Laboratory (LRDE)
//
// This file is part of Olena.
@@ -153,7 +153,7 @@ namespace mln
closest_point_with_map(const p_array<P>& X)
{
box3d box = geom::bbox(X);
- box.enlarge(0, box.nslices());
+ box.enlarge(0, box.nslis());
box.enlarge(1, box.nrows());
box.enlarge(2, box.ncols());
diff --git a/milena/tests/core/alias/box3d.cc b/milena/tests/core/alias/box3d.cc
index 925fd21..73d8b02 100644
--- a/milena/tests/core/alias/box3d.cc
+++ b/milena/tests/core/alias/box3d.cc
@@ -1,5 +1,5 @@
-// Copyright (C) 2007, 2008, 2009, 2010 EPITA Research and Development
-// Laboratory (LRDE)
+// Copyright (C) 2007, 2008, 2009, 2010, 2011 EPITA Research and
+// Development Laboratory (LRDE)
//
// This file is part of Olena.
//
@@ -33,5 +33,5 @@ int main()
using namespace mln;
box3d b = make::box3d(2, 6, 3);
- mln_assertion(b.nslices() == 2 && b.nrows() == 6 && b.ncols() == 3);
+ mln_assertion(b.nslis() == 2 && b.nrows() == 6 && b.ncols() == 3);
}
diff --git a/milena/tests/core/image/image3d.cc b/milena/tests/core/image/image3d.cc
index 2ebe3fa..90f12f0 100644
--- a/milena/tests/core/image/image3d.cc
+++ b/milena/tests/core/image/image3d.cc
@@ -1,5 +1,5 @@
-// Copyright (C) 2007, 2008, 2009, 2010 EPITA Research and Development
-// Laboratory (LRDE)
+// Copyright (C) 2007, 2008, 2009, 2010, 2011 EPITA Research and
+// Development Laboratory (LRDE)
//
// This file is part of Olena.
//
@@ -32,15 +32,15 @@ int main()
{
using namespace mln;
- const unsigned nslices = 3;
+ const unsigned nslis = 3;
const unsigned nrows = 4;
const unsigned ncols = 5;
const unsigned border = 4;
- image3d<int> f(nslices, nrows, ncols, border);
+ image3d<int> f(nslis, nrows, ncols, border);
- mln_assertion(f.nsites() == geom::nslices(f) * geom::nrows(f) * geom::ncols(f));
+ mln_assertion(f.nsites() == geom::nslis(f) * geom::nrows(f) * geom::ncols(f));
mln_assertion(f.nelements() == ((nrows + 2 * border)
* (ncols + 2 * border)
- * (nslices + 2 * border)));
+ * (nslis + 2 * border)));
}
diff --git a/milena/tests/geom/Makefile.am b/milena/tests/geom/Makefile.am
index 670561b..513d9d3 100644
--- a/milena/tests/geom/Makefile.am
+++ b/milena/tests/geom/Makefile.am
@@ -1,5 +1,5 @@
-# Copyright (C) 2007, 2008, 2009, 2010 EPITA Research and Development
-# Laboratory (LRDE).
+# Copyright (C) 2007, 2008, 2009, 2010, 2011 EPITA Research and
+# Development Laboratory (LRDE).
#
# This file is part of Olena.
#
@@ -32,7 +32,7 @@ ncols \
ninds \
nrows \
nsites \
-nslices \
+nslis \
pmin_pmax \
rotate \
seed2tiling \
@@ -55,7 +55,7 @@ ncols_SOURCES = ncols.cc
ninds_SOURCES = ninds.cc
nrows_SOURCES = nrows.cc
nsites_SOURCES = nsites.cc
-nslices_SOURCES = nslices.cc
+nslis_SOURCES = nslis.cc
pmin_pmax_SOURCES = pmin_pmax.cc
rotate_SOURCES = rotate.cc
seed2tiling_SOURCES = seed2tiling.cc
diff --git a/milena/tests/geom/nslices.cc b/milena/tests/geom/nslis.cc
similarity index 88%
rename from milena/tests/geom/nslices.cc
rename to milena/tests/geom/nslis.cc
index 5b67bfc..8588c07 100644
--- a/milena/tests/geom/nslices.cc
+++ b/milena/tests/geom/nslis.cc
@@ -1,5 +1,5 @@
-// Copyright (C) 2007, 2008, 2009, 2010 EPITA Research and Development
-// Laboratory (LRDE)
+// Copyright (C) 2007, 2008, 2009, 2010, 2011 EPITA Research and
+// Development Laboratory (LRDE)
//
// This file is part of Olena.
//
@@ -26,7 +26,7 @@
#include <mln/core/image/image3d.hh>
-#include <mln/geom/nslices.hh>
+#include <mln/geom/nslis.hh>
int main()
{
@@ -34,5 +34,5 @@ int main()
image3d<int> ima(3,4,5);
- mln_assertion(geom::nslices(ima) == 3);
+ mln_assertion(geom::nslis(ima) == 3);
}
diff --git a/milena/tests/io/pbms/load.cc b/milena/tests/io/pbms/load.cc
index d8843fe..79219a6 100644
--- a/milena/tests/io/pbms/load.cc
+++ b/milena/tests/io/pbms/load.cc
@@ -1,5 +1,5 @@
-// Copyright (C) 2009, 2010 EPITA Research and Development Laboratory
-// (LRDE)
+// Copyright (C) 2009, 2010, 2011 EPITA Research and Development
+// Laboratory (LRDE)
//
// This file is part of Olena.
//
@@ -55,7 +55,7 @@ int main()
image3d<bool> ima3d;
io::pbms::load(ima3d, files);
- mln_assertion(ima3d.nslices() == 2);
+ mln_assertion(ima3d.nslis() == 2);
mln_assertion(slice(ima3d, 0) == pic);
mln_assertion(slice(ima3d, 1) == pic2);
diff --git a/milena/tests/io/pgms/load.cc b/milena/tests/io/pgms/load.cc
index a64f83a..28069ad 100644
--- a/milena/tests/io/pgms/load.cc
+++ b/milena/tests/io/pgms/load.cc
@@ -1,5 +1,5 @@
-// Copyright (C) 2009, 2010 EPITA Research and Development Laboratory
-// (LRDE)
+// Copyright (C) 2009, 2010, 2011 EPITA Research and Development
+// Laboratory (LRDE)
//
// This file is part of Olena.
//
@@ -62,7 +62,7 @@ int main()
image3d<int_u8> ima3d;
io::pgms::load(ima3d, files);
- mln_assertion(ima3d.nslices() == 2);
+ mln_assertion(ima3d.nslis() == 2);
mln_assertion(slice(ima3d, 0) == lena);
mln_assertion(slice(ima3d, 1) == lena2);
}
diff --git a/milena/tests/io/ppms/load.cc b/milena/tests/io/ppms/load.cc
index 0d1272a..c6c0ef4 100644
--- a/milena/tests/io/ppms/load.cc
+++ b/milena/tests/io/ppms/load.cc
@@ -1,5 +1,5 @@
-// Copyright (C) 2009, 2010 EPITA Research and Development Laboratory
-// (LRDE)
+// Copyright (C) 2009, 2010, 2011 EPITA Research and Development
+// Laboratory (LRDE)
//
// This file is part of Olena.
//
@@ -64,7 +64,7 @@ int main()
image3d<rgb8> ima3d;
io::ppms::load(ima3d, files);
- mln_assertion(ima3d.nslices() == 2);
+ mln_assertion(ima3d.nslis() == 2);
mln_assertion(slice(ima3d, 0) == ima);
mln_assertion(slice(ima3d, 1) == ima2);
}
diff --git a/scribo/sandbox/green/mln/clustering/k_mean.hh
b/scribo/sandbox/green/mln/clustering/k_mean.hh
index 74acda7..30a05f1 100644
--- a/scribo/sandbox/green/mln/clustering/k_mean.hh
+++ b/scribo/sandbox/green/mln/clustering/k_mean.hh
@@ -1,4 +1,4 @@
-// Copyright (C) 2007,2008,2009,2010 EPITA LRDE
+// Copyright (C) 2007,2008,2009,2010, 2011 EPITA LRDE
//
// This file is part of Olena.
//
@@ -582,7 +582,7 @@ namespace mln
mln_precondition(input.is_valid());
mln_precondition(n == input.nrows() * input.ncols());
//mln_precondition(n == input.nrows());
- //mln_precondition(n == input.nrows() * input.ncols() * input.nslices());
+ //mln_precondition(n == input.nrows() * input.ncols() * input.nslis());
mln_piter(I) pi(input.domain());
unsigned i = -1;
diff --git a/scribo/sandbox/green/mln/display/project_histo.hh
b/scribo/sandbox/green/mln/display/project_histo.hh
index 9b9065e..30de616 100644
--- a/scribo/sandbox/green/mln/display/project_histo.hh
+++ b/scribo/sandbox/green/mln/display/project_histo.hh
@@ -1,5 +1,5 @@
-// Copyright (C) 2009, 2010 EPITA Research and Development Laboratory
-// (LRDE)
+// Copyright (C) 2009, 2010, 2011 EPITA Research and Development
+// Laboratory (LRDE)
//
// This file is part of Olena.
//
@@ -287,7 +287,7 @@ namespace mln
unsigned max = 0; // minimum as possible
def::coord pos = -1;
- for (def::coord blue = 0; blue < (signed)histo.nslices(); ++blue)
+ for (def::coord blue = 0; blue < (signed)histo.nslis(); ++blue)
{
if (max < opt::at(histo,blue,red,green))
{
@@ -306,9 +306,9 @@ namespace mln
}
else if (1 == direction) // red
{
- image2d< value::int_u<n> > arg_max(histo.ncols(), histo.nslices());
+ image2d< value::int_u<n> > arg_max(histo.ncols(), histo.nslis());
- for (def::coord blue = 0; blue < (signed)histo.nslices(); ++blue)
+ for (def::coord blue = 0; blue < (signed)histo.nslis(); ++blue)
for (def::coord green = 0; green < (signed)histo.ncols(); ++green)
{
unsigned max = 0; // minimum as possible
@@ -333,9 +333,9 @@ namespace mln
}
else // 2 == direction // green
{
- image2d< value::int_u<n> > arg_max(histo.nrows(), histo.nslices());
+ image2d< value::int_u<n> > arg_max(histo.nrows(), histo.nslis());
- for (def::coord blue = 0; blue < (signed)histo.nslices(); ++blue)
+ for (def::coord blue = 0; blue < (signed)histo.nslis(); ++blue)
for (def::coord red = 0; red < (signed)histo.nrows(); ++red)
{
unsigned max = 0; // minimum as possible
@@ -380,7 +380,7 @@ namespace mln
unsigned max = 0; // minimum as possible
def::coord pos = -1;
- for (def::coord blue = 0; blue < (signed)histo.nslices(); ++blue)
+ for (def::coord blue = 0; blue < (signed)histo.nslis(); ++blue)
{
if (max < opt::at(histo,blue,red,green))
{
@@ -399,9 +399,9 @@ namespace mln
}
else if (1 == direction) // red
{
- image2d<value::label_8> arg_max(histo.ncols(), histo.nslices());
+ image2d<value::label_8> arg_max(histo.ncols(), histo.nslis());
- for (def::coord blue = 0; blue < (signed)histo.nslices(); ++blue)
+ for (def::coord blue = 0; blue < (signed)histo.nslis(); ++blue)
for (def::coord green = 0; green < (signed)histo.ncols(); ++green)
{
unsigned max = 0; // minimum as possible
@@ -426,9 +426,9 @@ namespace mln
}
else // 2 == direction // green
{
- image2d<value::label_8> arg_max(histo.nrows(), histo.nslices());
+ image2d<value::label_8> arg_max(histo.nrows(), histo.nslis());
- for (def::coord blue = 0; blue < (signed)histo.nslices(); ++blue)
+ for (def::coord blue = 0; blue < (signed)histo.nslis(); ++blue)
for (def::coord red = 0; red < (signed)histo.nrows(); ++red)
{
unsigned max = 0; // minimum as possible
@@ -479,7 +479,7 @@ namespace mln
unsigned max = 0; // minimum as possible
def::coord pos = -1;
- for (def::coord blue = 0; blue < (signed)histo.nslices(); ++blue)
+ for (def::coord blue = 0; blue < (signed)histo.nslis(); ++blue)
{
if (max < opt::at(histo,blue,red,green))
{
@@ -505,9 +505,9 @@ namespace mln
}
else if (1 == direction) // red
{
- image2d< value::rgb8 > arg_max(histo.ncols(), histo.nslices());
+ image2d< value::rgb8 > arg_max(histo.ncols(), histo.nslis());
- for (def::coord blue = 0; blue < (signed)histo.nslices(); ++blue)
+ for (def::coord blue = 0; blue < (signed)histo.nslis(); ++blue)
for (def::coord green = 0; green < (signed)histo.ncols(); ++green)
{
unsigned max = 0; // minimum as possible
@@ -539,9 +539,9 @@ namespace mln
}
else // 2 == direction // green
{
- image2d< value::rgb8 > arg_max(histo.nrows(), histo.nslices());
+ image2d< value::rgb8 > arg_max(histo.nrows(), histo.nslis());
- for (def::coord blue = 0; blue < (signed)histo.nslices(); ++blue)
+ for (def::coord blue = 0; blue < (signed)histo.nslis(); ++blue)
for (def::coord red = 0; red < (signed)histo.nrows(); ++red)
{
unsigned max = 0; // minimum as possible
@@ -593,7 +593,7 @@ namespace mln
unsigned max = 0; // minimum as possible
def::coord pos = -1;
- for (def::coord blue = 0; blue < (signed)histo.nslices(); ++blue)
+ for (def::coord blue = 0; blue < (signed)histo.nslis(); ++blue)
{
if (max < opt::at(histo,blue,red,green))
{
@@ -612,9 +612,9 @@ namespace mln
}
else if (1 == direction) // red
{
- image2d< value::rgb<n> > arg_max(histo.ncols(), histo.nslices());
+ image2d< value::rgb<n> > arg_max(histo.ncols(), histo.nslis());
- for (def::coord blue = 0; blue < (signed)histo.nslices(); ++blue)
+ for (def::coord blue = 0; blue < (signed)histo.nslis(); ++blue)
for (def::coord green = 0; green < (signed)histo.ncols(); ++green)
{
unsigned max = 0; // minimum as possible
@@ -639,9 +639,9 @@ namespace mln
}
else // 2 == direction // green
{
- image2d< value::rgb<n> > arg_max(histo.nrows(), histo.nslices());
+ image2d< value::rgb<n> > arg_max(histo.nrows(), histo.nslis());
- for (def::coord blue = 0; blue < (signed)histo.nslices(); ++blue)
+ for (def::coord blue = 0; blue < (signed)histo.nslis(); ++blue)
for (def::coord red = 0; red < (signed)histo.nrows(); ++red)
{
unsigned max = 0; // minimum as possible
diff --git a/milena/mln/make/box3d.hh b/milena/mln/make/box3d.hh
index e12db48..14e1758 100644
--- a/milena/mln/make/box3d.hh
+++ b/milena/mln/make/box3d.hh
@@ -1,5 +1,5 @@
-// Copyright (C) 2007, 2008, 2009, 2010 EPITA Research and Development
-// Laboratory (LRDE)
+// Copyright (C) 2007, 2008, 2009, 2010, 2011 EPITA Research and
+// Development Laboratory (LRDE)
//
// This file is part of Olena.
//
@@ -42,15 +42,15 @@ namespace mln
/*! \brief Create an mln::box3d.
*
* \param[in] nslices Number of slices.
* \param[in] nrows Number of rows.
* \param[in] ncols Number of columns.
*
* \pre \p ninds != 0 and \p ncols != 0 and \p nslices != 0.
*
* \return A 3D box.
*/
- mln::box3d box3d(unsigned nslices, unsigned nrows, unsigned ncols);
+ mln::box3d box3d(unsigned nslis, unsigned nrows, unsigned ncols);
/*! \brief Create an mln::box3d.
@@ -77,11 +77,11 @@ namespace mln
# ifndef MLN_INCLUDE_ONLY
inline
- mln::box3d box3d(unsigned nslices, unsigned nrows, unsigned ncols)
+ mln::box3d box3d(unsigned nslis, unsigned nrows, unsigned ncols)
{
- mln_precondition(nrows != 0 && ncols != 0 && nslices != 0);
+ mln_precondition(nrows != 0 && ncols != 0 && nslis != 0);
mln::box3d tmp(point3d(0, 0, 0),
- point3d(static_cast<def::coord>(nslices - 1),
+ point3d(static_cast<def::coord>(nslis - 1),
static_cast<def::coord>(nrows - 1),
static_cast<def::coord>(ncols - 1)));
return tmp;
@@ -42,15 +42,15 @@ namespace mln
/*! \brief Create an mln::box3d.
*
- * \param[in] nslices Number of slices.
+ * \param[in] nslis Number of slices.
* \param[in] nrows Number of rows.
* \param[in] ncols Number of columns.
@@ -42,15 +42,15 @@ namespace mln
* \param[in] ncols Number of columns.
*
- * \pre \p ninds != 0 and \p ncols != 0 and \p nslices != 0.
+ * \pre \p ninds != 0 and \p ncols != 0 and \p nslis != 0.
*
* \return A 3D box.
--
1.7.2.5